@@ -1,10 +1,10 @@
 package App::BencherUtils;
 
-our $DATE = '2016-07-13'; # DATE
-our $VERSION = '0.17'; # VERSION
+our $DATE = '2016-10-20'; # DATE
+our $VERSION = '0.18'; # VERSION
 
 use 5.010001;
-use strict;
+use strict 'subs', 'vars';
 use warnings;
 use Log::Any::IfLOG '$log';
 
@@ -396,21 +396,47 @@ $SPEC{list_bencher_scenario_modules} = {
             schema => 'str*',
             pos => 0,
         },
+        detail => {
+            schema => 'bool*',
+            cmdline_aliases => {l=>{}},
+        },
     },
 };
 sub list_bencher_scenario_modules {
     require PERLANCAR::Module::List;
 
     my %args = @_;
+    my $q = lc($args{query} // '');
+    my $detail = $args{detail};
 
     my $res = PERLANCAR::Module::List::list_modules(
         "Bencher::Scenario::", {list_modules=>1, recurse=>1});
-    my @res = sort keys %$res;
-    for (@res) { s/^Bencher::Scenario::// }
+    my @res0 = sort keys %$res;
 
-    # XXX allow specifying query e.g. 'Accessors/*'
+    my @res;
+    my $resmeta = {};
+    for my $mod (@res0) {
+        (my $scenario_name = $mod) =~ s/^Bencher::Scenario:://;
+        next if length($q) && index(lc($scenario_name), $q) < 0;
+        if ($detail) {
+            (my $mod_pm = "$mod.pm") =~ s!::!/!g;
+            require $mod_pm;
+            my $scenario = ${"$mod\::scenario"};
+            push @res, {
+                name => $scenario_name,
+                summary => $scenario->{summary},
+                num_participants => scalar(@{$scenario->{participants}}),
+                num_datasets => $scenario->{datasets} ?
+                    scalar(@{$scenario->{datasets}}) : '-',
+            };
+        } else {
+            push @res, $scenario_name;
+        }
+    }
+    $resmeta = {'table.fields' => [qw/name summary num_participants num_datasets/]}
+        if $detail;
 
-    [200, "OK", \@res];
+    [200, "OK", \@res, $resmeta];
 }
 
 $SPEC{format_bencher_result} = {
@@ -486,7 +512,7 @@ App::BencherUtils - Utilities related to bencher
 
 =head1 VERSION
 
-This document describes version 0.17 of App::BencherUtils (from Perl distribution App-BencherUtils), released on 2016-07-13.
+This document describes version 0.18 of App::BencherUtils (from Perl distribution App-BencherUtils), released on 2016-10-20.
 
 =head1 SYNOPSIS
 
@@ -674,6 +700,8 @@ Arguments ('*' denotes required arguments):
 
 =over 4
 
+=item * B<detail> => I<bool>
+
 =item * B<query> => I<str>
 
 =back
